@@ -27,18 +27,19 @@ import (
 	"github.com/segmentfault/pacman/i18n"
 )
 
-// GetLang get language from header
-func GetLang(ctx *gin.Context) i18n.Language {
-	acceptLanguage := ctx.GetHeader(constant.AcceptLanguageFlag)
-	if len(acceptLanguage) == 0 {
-		return i18n.DefaultLanguage
-	}
-	return i18n.Language(acceptLanguage)
-}
-
 // GetLangByCtx get language from header
 func GetLangByCtx(ctx context.Context) i18n.Language {
-	acceptLanguage, ok := ctx.Value(constant.AcceptLanguageFlag).(i18n.Language)
+	if ginCtx, ok := ctx.(*gin.Context); ok {
+		acceptLanguage, ok := ginCtx.Get(constant.AcceptLanguageFlag)
+		if ok {
+			if acceptLanguage, ok := acceptLanguage.(i18n.Language); ok {
+				return acceptLanguage
+			}
+			return i18n.DefaultLanguage
+		}
+	}
+
+	acceptLanguage, ok := ctx.Value(constant.AcceptLanguageContextKey).(i18n.Language)
 	if ok {
 		return acceptLanguage
 	}
