@@ -34,7 +34,9 @@ func DumpAllData(dataConf *data.Database, dumpDataPath string) error {
 	if err != nil {
 		return err
 	}
-	defer db.Close()
+	defer func() {
+		_ = db.Close()
+	}()
 	if err = db.Ping(); err != nil {
 		return err
 	}
