@@ -43,7 +43,9 @@ func CheckDBConnection(dataConf *data.Database) bool {
 		fmt.Printf("connection database failed: %s\n", err)
 		return false
 	}
-	defer db.Close()
+	defer func() {
+		_ = db.Close()
+	}()
 	if err = db.Ping(); err != nil {
 		fmt.Printf("connection ping database failed: %s\n", err)
 		return false
@@ -59,7 +61,9 @@ func CheckDBTableExist(dataConf *data.Database) bool {
 		fmt.Printf("connection database failed: %s\n", err)
 		return false
 	}
-	defer db.Close()
+	defer func() {
+		_ = db.Close()
+	}()
 	if err = db.Ping(); err != nil {
 		fmt.Printf("connection ping database failed: %s\n", err)
 		return false
