@@ -54,4 +54,7 @@ var ProviderSetController = wire.NewSet(
 	NewBadgeController,
 	NewRenderController,
 	NewSidebarController,
+	NewMCPController,
+	NewAIController,
+	NewAIConversationController,
 )
