@@ -25,13 +25,19 @@ import (
 
 	"github.com/apache/answer/internal/base/path"
 	"github.com/apache/answer/internal/base/translator"
+	"github.com/joho/godotenv"
 )
 
 var (
-	port     = os.Getenv("INSTALL_PORT")
+	port     string
 	confPath = ""
 )
 
+func init() {
+	_ = godotenv.Load()
+	port = os.Getenv("INSTALL_PORT")
+}
+
 func Run(configPath string) {
 	confPath = configPath
 	// initialize translator for return internationalization error when installing.
