@@ -24,6 +24,7 @@ import (
 	"encoding/json"
 	"fmt"
 
+	"github.com/apache/answer/internal/base/constant"
 	"github.com/apache/answer/internal/entity"
 	"xorm.io/xorm"
 )
@@ -50,7 +51,7 @@ func addThemeAndPrivateMode(ctx context.Context, x *xorm.Engine) error {
 		}
 	}
 
-	themeConfig := `{"theme":"default","theme_config":{"default":{"navbar_style":"#0033ff","primary_color":"#0033ff"}}}`
+	themeConfig := fmt.Sprintf(`{"theme":"default","theme_config":{"default":{"navbar_style":"#0033ff","primary_color":"#0033ff"}},"layout":"%s"}`, constant.ThemeLayoutFullWidth)
 	themeSiteInfo := &entity.SiteInfo{
 		Type:    "theme",
 		Content: themeConfig,
