@@ -63,10 +63,12 @@ func (sr *siteInfoRepo) SaveByType(ctx context.Context, siteType string, data *e
 }
 
 // GetByType get site info by type
-func (sr *siteInfoRepo) GetByType(ctx context.Context, siteType string) (siteInfo *entity.SiteInfo, exist bool, err error) {
-	siteInfo = sr.getCache(ctx, siteType)
-	if siteInfo != nil {
-		return siteInfo, true, nil
+func (sr *siteInfoRepo) GetByType(ctx context.Context, siteType string, withoutCache ...bool) (siteInfo *entity.SiteInfo, exist bool, err error) {
+	if len(withoutCache) == 0 {
+		siteInfo = sr.getCache(ctx, siteType)
+		if siteInfo != nil {
+			return siteInfo, true, nil
+		}
 	}
 	siteInfo = &entity.SiteInfo{}
 	exist, err = sr.data.DB.Context(ctx).Where(builder.Eq{"type": siteType}).Get(siteInfo)
