@@ -28,7 +28,7 @@ import (
 	"github.com/apache/answer/internal/schema"
 	"github.com/apache/answer/internal/service/activity_common"
 	"github.com/apache/answer/internal/service/export"
-	"github.com/apache/answer/internal/service/notice_queue"
+	"github.com/apache/answer/internal/service/noticequeue"
 	"github.com/apache/answer/internal/service/siteinfo_common"
 	usercommon "github.com/apache/answer/internal/service/user_common"
 	"github.com/apache/answer/internal/service/user_external_login"
@@ -42,7 +42,7 @@ type ExternalNotificationService struct {
 	followRepo                 activity_common.FollowRepo
 	emailService               *export.EmailService
 	userRepo                   usercommon.UserRepo
-	notificationQueueService   notice_queue.ExternalNotificationQueueService
+	notificationQueueService   noticequeue.ExternalService
 	userExternalLoginRepo      user_external_login.UserExternalLoginRepo
 	siteInfoService            siteinfo_common.SiteInfoCommonService
 }
@@ -53,7 +53,7 @@ func NewExternalNotificationService(
 	followRepo activity_common.FollowRepo,
 	emailService *export.EmailService,
 	userRepo usercommon.UserRepo,
-	notificationQueueService notice_queue.ExternalNotificationQueueService,
+	notificationQueueService noticequeue.ExternalService,
 	userExternalLoginRepo user_external_login.UserExternalLoginRepo,
 	siteInfoService siteinfo_common.SiteInfoCommonService,
 ) *ExternalNotificationService {
