@@ -22,7 +22,7 @@ package report
 import (
 	"encoding/json"
 
-	"github.com/apache/answer/internal/service/event_queue"
+	"github.com/apache/answer/internal/service/eventqueue"
 
 	"github.com/apache/answer/internal/base/constant"
 	"github.com/apache/answer/internal/base/handler"
@@ -57,7 +57,7 @@ type ReportService struct {
 	commentCommonRepo comment_common.CommentCommonRepo
 	reportHandle      *report_handle.ReportHandle
 	configService     *config.ConfigService
-	eventQueueService event_queue.EventQueueService
+	eventQueueService eventqueue.Service
 }
 
 // NewReportService new report service
@@ -70,7 +70,7 @@ func NewReportService(
 	commentCommonRepo comment_common.CommentCommonRepo,
 	reportHandle *report_handle.ReportHandle,
 	configService *config.ConfigService,
-	eventQueueService event_queue.EventQueueService,
+	eventQueueService eventqueue.Service,
 ) *ReportService {
 	return &ReportService{
 		reportRepo:        reportRepo,
