@@ -21,9 +21,8 @@ import { memo } from 'react';
 import { useTranslation } from 'react-i18next';
 
 import ToolItem from '../toolItem';
-import { IEditorContext } from '../types';
+import { Editor } from '../types';
 
-let context: IEditorContext;
 const BlockQuote = () => {
   const { t } = useTranslation('translation', { keyPrefix: 'editor' });
 
@@ -33,21 +32,9 @@ const BlockQuote = () => {
     tip: `${t('blockquote.text')} (Ctrl+Q)`,
   };
 
-  const handleClick = (ctx) => {
-    context = ctx;
-    context.replaceLines((line) => {
-      const FIND_BLOCKQUOTE_RX = /^>\s+?/g;
-
-      if (line === `> ${t('blockquote.text')}`) {
-        line = '';
-      } else if (line.match(FIND_BLOCKQUOTE_RX)) {
-        line = line.replace(FIND_BLOCKQUOTE_RX, '');
-      } else {
-        line = `> ${line || t('blockquote.text')}`;
-      }
-      return line;
-    }, 2);
-    context.editor?.focus();
+  const handleClick = (editor: Editor) => {
+    editor.insertBlockquote(t('blockquote.text'));
+    editor.focus();
   };
 
   return <ToolItem {...item} onClick={handleClick} />;
