@@ -21,9 +21,8 @@ import { memo } from 'react';
 import { useTranslation } from 'react-i18next';
 
 import ToolItem from '../toolItem';
-import { IEditorContext } from '../types';
+import { Editor } from '../types';
 
-let context: IEditorContext;
 const Bold = () => {
   const { t } = useTranslation('translation', { keyPrefix: 'editor' });
   const item = {
@@ -33,10 +32,9 @@ const Bold = () => {
   };
   const DEFAULTTEXT = t('bold.text');
 
-  const handleClick = (ctx) => {
-    context = ctx;
-    context.wrapText('**', '**', DEFAULTTEXT);
-    context.editor?.focus();
+  const handleClick = (editor: Editor) => {
+    editor.insertBold(DEFAULTTEXT);
+    editor.focus();
   };
 
   return <ToolItem {...item} onClick={handleClick} />;
