@@ -21,9 +21,8 @@ import { memo } from 'react';
 import { useTranslation } from 'react-i18next';
 
 import ToolItem from '../toolItem';
-import { IEditorContext } from '../types';
+import { Editor } from '../types';
 
-let context: IEditorContext;
 const Hr = () => {
   const { t } = useTranslation('translation', { keyPrefix: 'editor' });
   const item = {
@@ -31,11 +30,9 @@ const Hr = () => {
     keyMap: ['Ctrl-r'],
     tip: `${t('hr.text')} (Ctrl+r)`,
   };
-  const handleClick = (ctx) => {
-    context = ctx;
-    const { appendBlock, editor } = context;
-    appendBlock('----------\n');
-    editor?.focus();
+  const handleClick = (editor: Editor) => {
+    editor.insertHorizontalRule();
+    editor.focus();
   };
 
   return <ToolItem {...item} onClick={handleClick} />;
