@@ -31,7 +31,6 @@ import Link from './link';
 import BlockQuote from './blockquote';
 import Image from './image';
 import Help from './help';
-import Chart from './chart';
 import File from './file';
 
 export {
@@ -49,6 +48,5 @@ export {
   BlockQuote,
   Image,
   Help,
-  Chart,
   File,
 };
