@@ -17,9 +17,12 @@
  * under the License.
  */
 
-import React, { FC, ReactNode } from 'react';
+import React, { FC, ReactNode, useEffect, useState } from 'react';
 
 import PluginKit, { Plugin, PluginType } from '@/utils/pluginKit';
+
+// Marker component for plugin insertion point
+export const PluginSlot: FC = () => null;
 /**
  * Note：Please set at least either of the `slug_name` and `type` attributes, otherwise no plugins will be rendered.
  *
@@ -29,13 +32,16 @@ import PluginKit, { Plugin, PluginType } from '@/utils/pluginKit';
  * @field type: Used to formulate the rendering of all plugins of this type.
  *              (if the `slug_name` attribute is set, it will be ignored)
  * @field prop: Any attribute you want to configure, e.g. `className`
+ *
+ * For editor type plugins, use <PluginSlot /> component as a marker to indicate where plugins should be inserted.
  */
 
 interface Props {
   slug_name?: string;
   type: PluginType;
   children?: ReactNode;
-  [prop: string]: any;
+  className?: string;
+  [key: string]: unknown;
 }
 
 const Index: FC<Props> = ({
@@ -45,29 +51,70 @@ const Index: FC<Props> = ({
   className,
   ...props
 }) => {
-  const pluginSlice: Plugin[] = [];
-  const plugins = PluginKit.getPlugins().filter((plugin) => plugin.activated);
+  const [pluginSlice, setPluginSlice] = useState<Plugin[]>([]);
+  const [isLoading, setIsLoading] = useState(true);
 
-  plugins.forEach((plugin) => {
-    if (type && slug_name) {
-      if (plugin.info.slug_name === slug_name && plugin.info.type === type) {
-        pluginSlice.push(plugin);
+  useEffect(() => {
+    let mounted = true;
+
+    const loadPlugins = async () => {
+      await PluginKit.initialization;
+
+      if (!mounted) return;
+
+      const plugins = PluginKit.getPlugins().filter(
+        (plugin) => plugin.activated,
+      );
+      console.log(
+        '[PluginRender] Loaded plugins:',
+        plugins.map((p) => p.info.slug_name),
+      );
+      const filtered: Plugin[] = [];
+
+      plugins.forEach((plugin) => {
+        if (type && slug_name) {
+          if (
+            plugin.info.slug_name === slug_name &&
+            plugin.info.type === type
+          ) {
+            filtered.push(plugin);
+          }
+        } else if (type) {
+          if (plugin.info.type === type) {
+            filtered.push(plugin);
+          }
+        } else if (slug_name) {
+          if (plugin.info.slug_name === slug_name) {
+            filtered.push(plugin);
+          }
+        }
+      });
+
+      if (mounted) {
+        setPluginSlice(filtered);
+        setIsLoading(false);
       }
-    } else if (type) {
-      if (plugin.info.type === type) {
-        pluginSlice.push(plugin);
-      }
-    } else if (slug_name) {
-      if (plugin.info.slug_name === slug_name) {
-        pluginSlice.push(plugin);
-      }
-    }
-  });
+    };
+
+    loadPlugins();
+
+    return () => {
+      mounted = false;
+    };
+  }, [slug_name, type]);
 
   /**
    * TODO: Rendering control for non-builtin plug-ins
    * ps: Logic such as version compatibility determination can be placed here
    */
+  if (isLoading) {
+    // Don't render anything while loading to avoid flashing
+    if (type === 'editor') {
+      return <div className={className}>{children}</div>;
+    }
+    return null;
+  }
+
   if (pluginSlice.length === 0) {
     if (type === 'editor') {
       return <div className={className}>{children}</div>;
@@ -76,20 +123,17 @@ const Index: FC<Props> = ({
   }
 
   if (type === 'editor') {
-    // index 16 is the position of the toolbar in the editor for plugins
-    const nodes = React.Children.map(children, (child, index) => {
-      if (index === 16) {
+    // Use PluginSlot marker to insert plugins at the correct position
+    const nodes = React.Children.map(children, (child) => {
+      // Check if this is the PluginSlot marker
+      if (React.isValidElement(child) && child.type === PluginSlot) {
         return (
           <>
-            {child}
             {pluginSlice.map((ps) => {
-              const PluginFC = ps.component;
-              return (
-                // @ts-ignore
-                <PluginFC key={ps.info.slug_name} {...props} />
-              );
+              const PluginFC = ps.component as FC<typeof props>;
+              return <PluginFC key={ps.info.slug_name} {...props} />;
             })}
-            <div className="toolbar-divider" />
+            {pluginSlice.length > 0 && <div className="toolbar-divider" />}
           </>
         );
       }
@@ -102,9 +146,10 @@ const Index: FC<Props> = ({
   return (
     <>
       {pluginSlice.map((ps) => {
-        const PluginFC = ps.component;
+        const PluginFC = ps.component as FC<
+          { className?: string } & typeof props
+        >;
         return (
-          // @ts-ignore
           <PluginFC key={ps.info.slug_name} className={className} {...props} />
         );
       })}
