@@ -32,8 +32,9 @@ import {
   Empty,
   QueryGroup,
   Modal,
+  TabNav,
 } from '@/components';
-import { ADMIN_LIST_STATUS } from '@/common/constants';
+import { ADMIN_LIST_STATUS, ADMIN_QA_NAV_MENUS } from '@/common/constants';
 import * as Type from '@/common/interface';
 import { deletePermanently, useQuestionSearch } from '@/services';
 import { pathFactory } from '@/router/pathFactory';
@@ -95,6 +96,7 @@ const Questions: FC = () => {
   return (
     <>
       <h3 className="mb-4">{t('page_title')}</h3>
+      <TabNav menus={ADMIN_QA_NAV_MENUS} />
       <div className="d-flex flex-wrap justify-content-between align-items-center">
         <Stack direction="horizontal" gap={3} className="mb-3">
           <QueryGroup
