@@ -224,13 +224,15 @@ const Smtp: FC = () => {
   return (
     <>
       <h3 className="mb-4">{t('page_title')}</h3>
-      <SchemaForm
-        schema={schema}
-        uiSchema={uiSchema}
-        formData={formData}
-        onChange={handleOnChange}
-        onSubmit={onSubmit}
-      />
+      <div className="max-w-748">
+        <SchemaForm
+          schema={schema}
+          uiSchema={uiSchema}
+          formData={formData}
+          onChange={handleOnChange}
+          onSubmit={onSubmit}
+        />
+      </div>
     </>
   );
 };
