@@ -26,6 +26,7 @@ export enum PluginType {
   Connector = 'connector',
   Search = 'search',
   Editor = 'editor',
+  EditorReplacement = 'editor_replacement',
   Route = 'route',
   Captcha = 'captcha',
   Render = 'render',
@@ -38,6 +39,7 @@ export interface PluginInfo {
   name?: string;
   description?: string;
   route?: string;
+  registrationMode?: 'multiple' | 'singleton';
 }
 
 export interface Plugin {
